use crate::packet::identifier::Identifier;

pub enum NodeManagement {
    Ping,
    RegisterNode { device_id: Identifier },
    RemoveNode,
    RegisterProperty {
        property_name: String,
        data_type: u8,
        read_only: bool
    },
    RemoveProperty {
        property_name: String,
    },
    Error {
        error_code: u8,
        metadata: [u8; 0xFFFF]
    }
}

#[allow(non_camel_case_types)]
pub enum NodeManagementError {
    net_duplicate_packet,
    net_broken_packet,
    net_invalid_packet,

    errc_not_registered
}

impl NodeManagementError {
    pub fn error_code(&self) -> u8 {
        match self {
            NodeManagementError::net_duplicate_packet => 0x00,
            NodeManagementError::net_broken_packet => 0x01,
            NodeManagementError::net_invalid_packet => 0x02,
            NodeManagementError::errc_not_registered => 0x10
        }
    }
}
